/*
 * Copyright © 2004 Red Hat, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of Red Hat not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  Red Hat makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * RED HAT DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL RED HAT
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Author:  Matthias Clasen, Red Hat, Inc.
 */

#include <stdio.h>
#include <stdlib.h>

#include <gtk/gtk.h>
#include <gdk/gdkx.h>

#include "clipboard-manager.h"

GdkFilterReturn 
manager_event_filter (GdkXEvent *xevent,
		      GdkEvent  *event,
		      gpointer   data)
{
  ClipboardManager *manager = (ClipboardManager *)data;

  if (clipboard_manager_process_event (manager, (XEvent *)xevent))
    return GDK_FILTER_REMOVE;
  else
    return GDK_FILTER_CONTINUE;
}

void
terminate_cb (void *data)
{
  gboolean *terminated = data;
  
  if (!*terminated)
    {
      *terminated = TRUE;
      
      gtk_main_quit ();
    }
}


int 
main (int argc, char *argv[])
{
  ClipboardManager *manager;
  gboolean terminated = False;

  gtk_init (&argc, &argv);

  if (clipboard_manager_check_running (gdk_display))
    {
      fprintf (stderr, "You can only run one clipboard manager at a time; exiting\n");
      exit (1);
    }

  if (!terminated)
    {
      manager = clipboard_manager_new (gdk_display,
				       gdk_error_trap_push, gdk_error_trap_pop,
				       terminate_cb, &terminated);
      if (!manager)
	{
	  fprintf (stderr, "Could not create clipboard manager!\n");
	  exit (1);
	}
    }

  gdk_window_add_filter (NULL, manager_event_filter, manager);
  
  if (!terminated)
    gtk_main ();
  
  clipboard_manager_destroy (manager);

  return 0;

}
